packagesample
=============

A simple python auto-generated rst project file.

To install it
-------------

::

    $ sudo pip install packagesample

Usage
-----

::

    usage: packagesample [-h] [--chicken]

    packagesample

    optional arguments:
      -h, --help            show this help message and exit
      --chicken             Chicken mode (optional). Does NOT CHANGE anything.

Contributions
-------------

Bug reports, fixes, or features? Feel free to open an issue or pull request any time.

License
--------

Copyright (c) 2014 <YOUR_NAME> Licensed under MIT_.

.. _MIT: http://opensource.org/licenses/MIT